pub struct AddrInVersion {
untrusted_services: PeerServices,
addr: PeerSocketAddr,
}Expand description
The format used for Bitcoin node addresses in version messages.
Contains a node address and services, without a last-seen time.
Fields
untrusted_services: PeerServicesThe unverified services for the peer at addr.
These services were advertised by the peer at addr,
then gossiped via another peer.
Security
untrusted_services on gossiped peers may be invalid due to outdated
records, older peer versions, or buggy or malicious peers.
addr: PeerSocketAddrThe peer’s canonical socket address. IPv4 addresses are serialized as an IPv4-mapped IPv6 address.
Implementations
Sourceimpl AddrInVersion
impl AddrInVersion
Sourcepub fn new(
socket_addr: impl Into<PeerSocketAddr>,
untrusted_services: PeerServices,
) -> Self
pub fn new( socket_addr: impl Into<PeerSocketAddr>, untrusted_services: PeerServices, ) -> Self
Returns a new version message address based on its fields.
Sourcepub fn addr(&self) -> PeerSocketAddr
pub fn addr(&self) -> PeerSocketAddr
Returns the canonical address for this peer.
Sourcepub fn untrusted_services(&self) -> PeerServices
pub fn untrusted_services(&self) -> PeerServices
Returns the services for this peer.